Controls how excess properties (keys not in shape) are handled.
'allow'
'reject'
This option only affects runtime validation behavior. The value type is always exact regardless of the setting.
Controls how excess properties (keys not in shape) are handled.
'allow'(default) — accept excess properties at runtime'reject'— reject objects with excess properties at runtimeThis option only affects runtime validation behavior. The value type is always exact regardless of the setting.