cast : Cast function (returns the original value, no transformation)
fill : Default value filling function
validate : A base function to be used in is and assertIs. validate
returns Result.Ok if the value is of Type A, otherwise returns Result.Err
with structured validation error information.
typeName: Name for this typeis: Type guard functionassertIs: Type assertion functioncast: Cast function (returns the original value, no transformation)fill: Default value filling functionvalidate: A base function to be used inisandassertIs.validatereturns Result.Ok if the value is of Type A, otherwise returns Result.Err with structured validation error information.